==> httpd-2.0.61.tar.bz2: httpd-2.0.61/support/win32/ApacheMonitor.h <==
/* Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* Resource definitions for ApacheMonitor.rc and ApacheMonitor.c
 */

#define IDD_DLGSERVICES                 101
#define IDS_APMONITORTITLE              102
#define IDS_APMONITORCLASS              103
#define IDM_RESTORE                     104
#define IDM_EXIT                        105
#define IDI_APSRVMON                    106
#define IDI_ICOSTOP                     107
#define IDI_ICORUN                      108
#define IDC_STATBAR                     109
#define IDC_SSTATUS                     110
#define IDB_BMPSTOP                     111
#define IDB_BMPRUN                      112
#define IDB_BMPHEADER                   114
#define IDL_SERVICES                    115
#define IDL_STDOUT                      116
#define IDC_SSTART                      117
#define IDC_SSTOP                       118
#define IDC_SRESTART                    119
#define IDC_SEXIT                       120
#define IDC_SMANAGER                    121
#define IDD_DLGCONNECT                  122
#define IDC_LREMOTE                     123
#define IDC_LBROWSE                     124
#define IDC_COMPUTER                    125
#define IDC_SCONNECT                    126
#define IDC_SDISCONN                    127
#define IDS_MSG_FIRST                   256
#define IDS_MSG_APPRUNNING              256
#define IDS_MSG_ERROR                   257
#define IDS_MSG_RUNNINGALL              258
#define IDS_MSG_RUNNING                 259
#define IDS_MSG_RUNNINGNONE             260
#define IDS_MSG_NOSERVICES              261
#define IDS_MSG_MNUSERVICES             262
#define IDS_MSG_MNUSHOW                 263
#define IDS_MSG_MNUEXIT                 264
#define IDS_MSG_SRVSTART                265
#define IDS_MSG_SRVSTARTED              266
#define IDS_MSG_SRVSTOP                 267
#define IDS_MSG_SRVSTOPPED              268
#define IDS_MSG_SRVRESTART              269
#define IDS_MSG_SRVRESTARTED            270
#define IDS_MSG_SRVFAILED               271
#define IDS_MSG_SSTART                  272
#define IDS_MSG_SSTOP                   273
#define IDS_MSG_SRESTART                274
#define IDS_MSG_SERVICES                275
#define IDS_MSG_CONNECT                 276
#define IDS_MSG_ECONNECT                277
#define IDS_MSG_LAST                    277
#define IDM_SM_SERVICE                  0x1100
#define IDM_SM_START                    0x1200
#define IDM_SM_STOP                     0x1400
#define IDM_SM_RESTART                  0x1800
#define IDC_STATIC                      -1

==> httpd-2.4.1.tar.bz2: httpd-2.4.1/support/win32/ApacheMonitor.h <==
/* Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file  ApacheMonitor.h
 * @brief Resource definitions for ApacheMonitor.rc and ApacheMonitor.c
 */
#define BIN_NAME  ApacheMonitor.exe

#define IDD_DLGSERVICES                 101
#define IDS_APMONITORTITLE              102
#define IDS_APMONITORCLASS              103
#define IDM_RESTORE                     104
#define IDM_EXIT                        105
#define IDI_APSRVMON                    106
#define IDI_ICOSTOP                     107
#define IDI_ICORUN                      108
#define IDC_STATBAR                     109
#define IDC_SSTATUS                     110
#define IDB_BMPSTOP                     111
#define IDB_BMPRUN                      112
#define IDB_BMPHEADER                   114
#define IDL_SERVICES                    115
#define IDL_STDOUT                      116
#define IDC_SSTART                      117
#define IDC_SSTOP                       118
#define IDC_SRESTART                    119
#define IDC_SMANAGER                    121
#define IDD_DLGCONNECT                  122
#define IDC_LREMOTE                     123
#define IDC_LBROWSE                     124
#define IDC_COMPUTER                    125
#define IDC_SCONNECT                    126
#define IDC_SDISCONN                    127
#define IDS_MSG_FIRST                   256
#define IDS_MSG_APPRUNNING              256
#define IDS_MSG_ERROR                   257
#define IDS_MSG_RUNNINGALL              258
#define IDS_MSG_RUNNING                 259
#define IDS_MSG_RUNNINGNONE             260
#define IDS_MSG_NOSERVICES              261
#define IDS_MSG_MNUSERVICES             262
#define IDS_MSG_MNUSHOW                 263
#define IDS_MSG_MNUEXIT                 264
#define IDS_MSG_SRVSTART                265
#define IDS_MSG_SRVSTARTED              266
#define IDS_MSG_SRVSTOP                 267
#define IDS_MSG_SRVSTOPPED              268
#define IDS_MSG_SRVRESTART              269
#define IDS_MSG_SRVRESTARTED            270
#define IDS_MSG_SRVFAILED               271
#define IDS_MSG_SSTART                  272
#define IDS_MSG_SSTOP                   273
#define IDS_MSG_SRESTART                274
#define IDS_MSG_SERVICES                275
#define IDS_MSG_CONNECT                 276
#define IDS_MSG_ECONNECT                277
#define IDS_MSG_OK                      278
#define IDS_MSG_LAST                    278
#define IDM_SM_SERVICE                  0x1100
#define IDM_SM_START                    0x1200
#define IDM_SM_STOP                     0x1400
#define IDM_SM_RESTART                  0x1800
#define IDC_STATIC                      -1
